==> symfony_5.4.4+dfsg.orig.tar.xz: symfony-5.4.4/src/Symfony/Component/Intl/Resources/data/locales/sr_Cyrl_XK.php <==
<?php

return [
    'Names' => [
        'bm' => 'бамананкан',
        'bm_ML' => 'бамананкан (Мали)',
        'bn' => 'бангла',
        'bn_BD' => 'бангла (Бангладеш)',
        'bn_IN' => 'бангла (Индија)',
        'cs_CZ' => 'чешки (Чешка Република)',
        'en_HK' => 'енглески (САР Хонгконг)',
        'en_KN' => 'енглески (Свети Китс и Невис)',
        'en_MO' => 'енглески (САР Макао)',
        'en_UM' => 'енглески (Мања удаљена острва САД)',
        'en_VC' => 'енглески (Свети Винсент и Гренадини)',
        'ff' => 'фулах',
        'ff_CM' => 'фулах (Камерун)',
        'ff_GN' => 'фулах (Гвинеја)',
        'ff_Latn' => 'фулах (латиница)',
        'ff_Latn_BF' => 'фулах (латиница, Буркина Фасо)',
        'ff_Latn_CM' => 'фулах (латиница, Камерун)',
        'ff_Latn_GH' => 'фулах (латиница, Гана)',
        'ff_Latn_GM' => 'фулах (латиница, Гамбија)',
        'ff_Latn_GN' => 'фулах (латиница, Гвинеја)',
        'ff_Latn_GW' => 'фулах (латиница, Гвинеја-Бисао)',
        'ff_Latn_LR' => 'фулах (латиница, Либерија)',
        'ff_Latn_MR' => 'фулах (латиница, Мауританија)',
        'ff_Latn_NE' => 'фулах (латиница, Нигер)',
        'ff_Latn_NG' => 'фулах (латиница, Нигерија)',
        'ff_Latn_SL' => 'фулах (латиница, Сијера Леоне)',
        'ff_Latn_SN' => 'фулах (латиница, Сенегал)',
        'ff_MR' => 'фулах (Мауританија)',
        'ff_SN' => 'фулах (Сенегал)',
        'fr_CG' => 'француски (Конго)',
        'fr_PM' => 'француски (Свети Пјер и Микелон)',
        'fr_RE' => 'француски (Реунион)',
        'ln_CG' => 'лингала (Конго)',
        'lo' => 'лаошки',
        'lo_LA' => 'лаошки (Лаос)',
        'pt_CV' => 'португалски (Кабо Верде)',
        'pt_MO' => 'португалски (САР Макао)',
        'si' => 'синхалски',
        'si_LK' => 'синхалски (Шри Ланка)',
        'xh' => 'исикоса',
        'xh_ZA' => 'исикоса (Јужноафричка Република)',
        'zh_HK' => 'кинески (САР Хонгконг)',
        'zh_Hans_HK' => 'кинески (поједностављено кинеско писмо, САР Хонгконг)',
        'zh_Hans_MO' => 'кинески (поједностављено кинеско писмо, САР Макао)',
        'zh_Hant_HK' => 'кинески (традиционално кинеско писмо, САР Хонгконг)',
        'zh_Hant_MO' => 'кинески (традиционално кинеско писмо, САР Макао)',
        'zh_MO' => 'кинески (САР Макао)',
        'zu' => 'исизулу',
        'zu_ZA' => 'исизулу (Јужноафричка Република)',
    ],
];

==> symfony_8.0.5+dfsg.orig.tar.xz: symfony-8.0.5/src/Symfony/Component/Intl/Resources/data/locales/sr_Cyrl_XK.php <==
<?php

return [
    'Names' => [
        'bm' => 'бамананкан',
        'bm_ML' => 'бамананкан (Мали)',
        'bn' => 'бангла',
        'bn_BD' => 'бангла (Бангладеш)',
        'bn_IN' => 'бангла (Индија)',
        'cs_CZ' => 'чешки (Чешка Република)',
        'en_CZ' => 'енглески (Чешка Република)',
        'en_HK' => 'енглески (САР Хонгконг)',
        'en_KN' => 'енглески (Свети Китс и Невис)',
        'en_MO' => 'енглески (САР Макао)',
        'en_UM' => 'енглески (Мања удаљена острва САД)',
        'en_VC' => 'енглески (Свети Винсент и Гренадини)',
        'ff' => 'фулах',
        'ff_Adlm' => 'фулах (адлам)',
        'ff_Adlm_BF' => 'фулах (адлам, Буркина Фасо)',
        'ff_Adlm_CM' => 'фулах (адлам, Камерун)',
        'ff_Adlm_GH' => 'фулах (адлам, Гана)',
        'ff_Adlm_GM' => 'фулах (адлам, Гамбија)',
        'ff_Adlm_GN' => 'фулах (адлам, Гвинеја)',
        'ff_Adlm_GW' => 'фулах (адлам, Гвинеја-Бисао)',
        'ff_Adlm_LR' => 'фулах (адлам, Либерија)',
        'ff_Adlm_MR' => 'фулах (адлам, Мауританија)',
        'ff_Adlm_NE' => 'фулах (адлам, Нигер)',
        'ff_Adlm_NG' => 'фулах (адлам, Нигерија)',
        'ff_Adlm_SL' => 'фулах (адлам, Сијера Леоне)',
        'ff_Adlm_SN' => 'фулах (адлам, Сенегал)',
        'ff_CM' => 'фулах (Камерун)',
        'ff_GN' => 'фулах (Гвинеја)',
        'ff_Latn' => 'фулах (латиница)',
        'ff_Latn_BF' => 'фулах (латиница, Буркина Фасо)',
        'ff_Latn_CM' => 'фулах (латиница, Камерун)',
        'ff_Latn_GH' => 'фулах (латиница, Гана)',
        'ff_Latn_GM' => 'фулах (латиница, Гамбија)',
        'ff_Latn_GN' => 'фулах (латиница, Гвинеја)',
        'ff_Latn_GW' => 'фулах (латиница, Гвинеја-Бисао)',
        'ff_Latn_LR' => 'фулах (латиница, Либерија)',
        'ff_Latn_MR' => 'фулах (латиница, Мауританија)',
        'ff_Latn_NE' => 'фулах (латиница, Нигер)',
        'ff_Latn_NG' => 'фулах (латиница, Нигерија)',
        'ff_Latn_SL' => 'фулах (латиница, Сијера Леоне)',
        'ff_Latn_SN' => 'фулах (латиница, Сенегал)',
        'ff_MR' => 'фулах (Мауританија)',
        'ff_SN' => 'фулах (Сенегал)',
        'fr_CG' => 'француски (Конго)',
        'fr_PM' => 'француски (Свети Пјер и Микелон)',
        'fr_RE' => 'француски (Реунион)',
        'ln_CG' => 'лингала (Конго)',
        'lo' => 'лаошки',
        'lo_LA' => 'лаошки (Лаос)',
        'pt_CV' => 'португалски (Кабо Верде)',
        'pt_MO' => 'португалски (САР Макао)',
        'si' => 'синхалски',
        'si_LK' => 'синхалски (Шри Ланка)',
        'xh' => 'исикоса',
        'xh_ZA' => 'исикоса (Јужноафричка Република)',
        'zh_HK' => 'кинески (САР Хонгконг)',
        'zh_Hans_HK' => 'кинески (поједностављено кинеско писмо, САР Хонгконг)',
        'zh_Hans_MO' => 'кинески (поједностављено кинеско писмо, САР Макао)',
        'zh_Hant_HK' => 'кинески (традиционално кинеско писмо, САР Хонгконг)',
        'zh_Hant_MO' => 'кинески (традиционално кинеско писмо, САР Макао)',
        'zh_MO' => 'кинески (САР Макао)',
        'zu' => 'исизулу',
        'zu_ZA' => 'исизулу (Јужноафричка Република)',
    ],
];
